@@ -1,7 +1,7 @@
 // qxgeditOptions.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2022, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2024, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -57,8 +57,8 @@ public:
 	void print_usage(const QString& arg0);
 #endif
 
-	// Startup supplied session file.
-	QString sSessionFile;
+	// Startup supplied session file(s).
+	QStringList sessionFiles;
 
 	// Display options...
 	bool    bConfirmReset;
